class CargoSweep < Formula
  desc "Utility for cleaning up unused build files generated by Cargo"
  homepage "https://github.com/holmgr/cargo-sweep"
  url "https://github.com/holmgr/cargo-sweep/archive/refs/tags/v0.7.0.tar.gz"
  sha256 "21004272ffacbe19b5e2b6c521a021eb55abd24e96599fc5049c650abb708af2"
  license "MIT"
  head "https://github.com/holmgr/cargo-sweep.git", branch: "master"

  depends_on "rust" => :build
  depends_on "rustup-init" => :test

  def install
    system "cargo", "install", "--no-default-features", *std_cargo_args
  end

  test do
    assert_equal "cargo-sweep #{version}", shell_output(bin/"cargo-sweep -V").strip
    ENV["RUSTUP_INIT_SKIP_PATH_CHECK"] = "yes"
    rustup_init = Formula["rustup-init"].bin/"rustup-init"
    system rustup_init, "-y", "--profile", "minimal", "--default-toolchain", "beta", "--no-modify-path"
    ENV.prepend_path "PATH", HOMEBREW_CACHE/"cargo_cache/bin"

    crate = testpath/"demo-crate"
    mkdir crate do
      (crate/"src/main.rs").write <<~EOS
        fn main() {
          println!("Hello BrewTestBot!");
        }
      EOS
      (crate/"Cargo.toml").write <<~EOS
        [package]
        name = "demo-crate"
        version = "0.1.0"
        license = "MIT"
      EOS

      system "cargo", "build"

      output = shell_output("cargo sweep --time 0").strip
      # test that there are some bytes cleaned
      assert_match(/^\[INFO\] Cleaned \d+\.\d+ [KMG]iB/, output)
    end
  end
end
